@@ -185,7 +185,7 @@ void addWordsFromFile(WordMap &map, const QString &filename, QTextCodec *codec)
     QXmlInputSource source(&xmlfile);
     XMLParser parser;
     QXmlSimpleReader reader;
-    reader.setFeature(QStringLiteral("http://trolltech.com/xml/features/report-start-end-entity"), true);
+    reader.setFeature(QStringLiteral("http://qt-project.org/xml/features/report-start-end-entity"), true);
     reader.setContentHandler(&parser);
 
     WordMap words;
